
# The different «textOverflow» options
options = [
	"ellipsis"
	"clip"
]


# Visible background for the Text Layers
textLayer1.backgroundColor = "#eee"
textLayer2.backgroundColor = "#eee"


# Set the height of «textLayer2» to only two lines
textLayer2.height = ( textLayer2.fontSize * textLayer2.lineHeight ) * 2


# Place the Text Layers next to each other when in landscape
if Screen.height < Screen.width
	# Center horizontally
	textLayer1.y = Align.center
	textLayer2.y = textLayer1.y
	# equal horizontal spacing between the text blocks
	textLayer1.x = ( whiteBackground.width - ( textLayer1.width * 2 ) ) / 3
	textLayer2.x = ( textLayer1.x * 2 ) + textLayer1.width

# Functions for the slider

# round number to a set amount
round = (number, nearest) ->
	Math.round(number / nearest) * nearest


# - add dots for increments to slider
# - enforce increments
# - change title on value change

applyIncrements = (slider,options) ->
	
	latestOption = null
	
	sizeOfDots = slider.height + 2
	stepAmount = options.length
	
	stepDistanceDots = ( slider.width - sizeOfDots ) / ( stepAmount - 1 )
	stepDistanceKnob = slider.width / ( stepAmount - 1 )
	
	for i in [0...stepAmount]
		dot = new Layer 
			size: sizeOfDots
			borderRadius: sizeOfDots / 1.5
			superLayer: slider
			backgroundColor: artboard.backgroundColor
			x: (stepDistanceDots * i)
		
		dot.placeBehind slider.knob
		dot.y = Align.center
	
	slider.min = 0
	slider.max = stepAmount-1
	
	slider.onValueChange ->
		if options[Utils.round @value] isnt latestOption
			# make the text a bit smaller
			textLayer1.scale = 0.95
			textLayer2.scale = 0.95
			# apply the new value
			textLayer1.textOverflow = options[Utils.round @value]
			textLayer2.textOverflow = options[Utils.round @value]
			# scale back up
			textLayer1.animate
				scale: 1
				options:
					time: .3
					curve: "Spring"
			textLayer2.animate
				scale: 1
				options:
					time: .3
					curve: "Spring"
			
			latestOption = options[Utils.round @value]
		
		if Utils.round @value is 0
			title.template =
				v: ""
				d: "«default»"
		else
			title.template =
				v: "\"#{options[Utils.round @value]}\""
				d: ""
	
	slider.knob.draggable.updatePosition = (point) ->
		point.x = round(point.x, stepDistanceKnob) - (slider.knob.width / 2)
		return point

# Setup title

title.template =
	v: ""
	d: "«default»"

if Screen.height > Screen.width		# portrait orientation ?
	if Screen.height <= 667			# on an iPhone 6 (or smaller) ?
		title.fontSize = 18

# Slider
slider = new SliderComponent
	height: 5
	width: Screen.width - 50
	knobSize: 25
	backgroundColor: "rgba(255,255,255,0.5)"
	x: 25
	maxY: Screen.height - 30
slider.fill.backgroundColor = "#fff"

# add the default option
options.unshift null

# add interval points to the slider
applyIncrements slider, options
